@@ -23,7 +23,7 @@
  * documentation for such software.
  *
  *   This  software is  distribuited  under  the  GNU General  Public
- * License  (version  2, June  1991). Check  the  file  'COPING'  for
+ * License  (version  2, June  1991). Check  the  file  'COPYING'  for
  * more  infos. Some  parts of  this  software  derive  from the  NFS
  * implementation in the Linux kernel 2.0.x.
  *
@@ -38,6 +38,10 @@
 /* Copyright (C) 1992 Eric Young - see COPYING for more details */
 /* Collected and modified by Werner Almesberger */
 
+#include <linux/autoconf.h>
+
+#ifdef TCFS_DES
+
 #include <linux/kdes.h>
 
 
@@ -584,3 +588,5 @@ void des_set_key(des_cblock *key,des_key_schedule schedule)
 		*(k++)=s&0xffffffff;
 		}
 	}
+
+#endif
\ No newline at end of file
