@@ -23,7 +23,7 @@
  * documentation for such software.
  *
  *   This  software is  distribuited  under  the  GNU General  Public
- * License  (version  2, June  1991). Check  the  file  'COPING'  for
+ * License  (version  2, June  1991). Check  the  file  'COPYING'  for
  * more  infos. Some  parts of  this  software  derive  from the  NFS
  * implementation in the Linux kernel 2.0.x.
  *
@@ -58,7 +58,7 @@
 #include <linux/pagemap.h>
 
 #include "xattr_client.h"
-#include "desitfc.h"
+#include "cypitfc.h"
 #include <asm/segment.h>
 
 #ifdef TCFS_PROC_DEBUG
@@ -415,12 +415,12 @@ int tcfs_proc_cryptdir(struct inode *inode, char mode,struct file *filp,struct h
 			strcpy(newname,tmp);
 			index=strlen(newname)+1;
 			if (mode!=0) { /* Removing secure flag */
-				kendes(newname,(index &0xfff8)+8,htmp->ks);
+				kencrypt(newname,(index &0xfff8)+8,htmp->ks);
 				tcfsencode(newname,(index &0xfff8)+8);
 			}
 			else {
 				index=tcfsdecode(newname,index);
-				kdedes(newname,(index & 0xfff8)+8,htmp->ks);
+				kdecrypt(newname,(index & 0xfff8)+8,htmp->ks);
 			}
 			ret=tcfs_proc_rename(TCFS_SERVER(inode),TCFS_FH(inode),tmp,TCFS_FH(inode),newname,0);
 			if (ret<0) {
@@ -509,12 +509,13 @@ int tcfs_endes(struct inode *inode,int mode,struct file *filp)
 						if (read % 8!=0) {
 							read+=8-(read %8);
 						}
-						mkendes(data,read,htmp->ks);
+						mkencrypt(data,read,htmp->ks);
 					} else { /* Removing Secure Flag */
-						mkdedes(data,read,htmp->ks);
+						mkdecrypt(data,read,htmp->ks);
 						if (off+1024>=size) { 
 							/* We are at the end of file so we remove spure bytes */
-							read-=8-inode->u.tcfs_i.tcfs_fl.bf.spure;
+							if (inode->u.tcfs_i.tcfs_fl.bf.spure>0)
+								read-=8-inode->u.tcfs_i.tcfs_fl.bf.spure;
 						}
 					}
 				} else {
